IOSFindInteractionController class
This class represents the controller used by the WebView to add
text-finding capabilities, such as the "Find on page" feature.
Officially Supported Platforms/Implementations:
- Android native WebView
- iOS
- MacOS
- Inheritance
-
- Object
- PlatformInterface
- IOSFindInteractionController
Constructors
- IOSFindInteractionController(PlatformFindInteractionControllerCreationParams params)
- Constructs a IOSFindInteractionController.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onFindResultReceived → void Function(PlatformFindInteractionController controller, int activeMatchOrdinal, int numberOfMatches, bool isDoneCounting)?
-
Event fired as find-on-page operations progress.
The listener may be notified multiple times while the operation is underway, and the
numberOfMatchesvalue should not be considered final unlessisDoneCountingis true.no setterinherited - params → PlatformFindInteractionControllerCreationParams
-
The parameters used to initialize the
PlatformFindInteractionController.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearMatches(
) → Future< void> - Clears the highlighting surrounding text matches created by findAll.
- Dismisses the find panel, if present.
-
dispose(
{bool isKeepAlive = false}) → void - Disposes the controller.
-
findAll(
{String? find}) → Future< void> -
Finds all instances of find on the page and highlights them. Notifies
PlatformFindInteractionController.onFindResultReceivedlistener. -
findNext(
{bool forward = true}) → Future< void> -
Highlights and scrolls to the next match found by findAll. Notifies
PlatformFindInteractionController.onFindResultReceivedlistener. -
getActiveFindSession(
) → Future< FindSession?> - If there's a currently active find session, returns the active find session.
-
getSearchText(
) → Future< String?> - Get the search text used.
- A Boolean value that indicates when the find panel displays onscreen.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
- Begins a search, displaying the find panel.
-
setSearchText(
String? searchText) → Future< void> - Pre-populate the search text to be used.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateResultCount(
) → Future< void> - Updates the results the interface displays for the active search.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited