IOSWebMessagePortCreationParams class
Object specifying creation parameters for creating a IOSWebMessagePort.
When adding additional fields make sure they can be null or have a default
value to avoid breaking changes. See PlatformWebMessagePortCreationParams for
more information.
- Annotations
Constructors
- IOSWebMessagePortCreationParams({required int index})
-
Creates a new IOSWebMessagePortCreationParams instance.
const
- IOSWebMessagePortCreationParams.fromPlatformWebMessagePortCreationParams(PlatformWebMessagePortCreationParams params)
-
Creates a IOSWebMessagePortCreationParams instance based on
PlatformWebMessagePortCreationParams.factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited