IOSWebStorageManagerCreationParams class

Object specifying creation parameters for creating a IOSWebStorageManager.

When adding additional fields make sure they can be null or have a default value to avoid breaking changes. See PlatformWebStorageManagerCreationParams for more information.

Annotations

Constructors

IOSWebStorageManagerCreationParams(PlatformWebStorageManagerCreationParams params)
Creates a new IOSWebStorageManagerCreationParams instance.
const
IOSWebStorageManagerCreationParams.fromPlatformWebStorageManagerCreationParams(PlatformWebStorageManagerCreationParams params)
Creates a IOSWebStorageManagerCreationParams instance based on PlatformWebStorageManagerCreationParams.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited